@@ -1,22 +1,26 @@
 import json
 from dataclasses import dataclass
 from datetime import datetime
-from enum import Enum
+from enum import StrEnum
 
 
-class Queue(str, Enum):
+class Queue(StrEnum):
     integrations = "integrations"
-    scouty = "scouty"
-    jobs = "jobs"
+    candidates = "candidates"
+    vacancies = "vacancies"
+    strategy = "strategy"
     insights = "insights"
     billing = "billing"
     iam = "iam"
+    notifications = "notifications"
+    live_updates = "live-updates"
 
 
 @dataclass
 class Event:
     event_type: str
-    event: dict
+    payload: dict
+    organization_id: str | None = None
     created_on: datetime = None
 
     def encode(self) -> bytes:
@@ -26,5 +30,5 @@ class Event:
 
 @dataclass
 class Message:
-    body: Event
+    event: Event
     queue: Queue
