@@ -2,14 +2,11 @@ import uuid
 
 from sqlalchemy import Column, JSON
 from sqlmodel import Field
-from sqlalchemy.orm import registry
 
-from ..general.models import BaseModel, ClintBaseModel
+from ..general.models import IntegrationsOrganizationModel, IntegrationsModel
 
 
-mapper_registry = registry()
-
-class Integration(ClintBaseModel, table=True):
+class Integration(IntegrationsModel, table=True):
     name: str = Field(index=True)
     icon: str = Field(index=True)
     type: str = Field(index=True)
@@ -18,9 +15,11 @@ class Integration(ClintBaseModel, table=True):
     description: str = Field(index=True, nullable=True)
     code_reference: str = Field(index=True)
     setup_config: dict = Field(sa_column=Column(JSON))
+    order: int = Field(default=0)
 
 
-class Link(BaseModel, table=True):
-    company: uuid.UUID = Field(index=True)
+class Link(IntegrationsOrganizationModel, table=True):
+    name: str = Field(index=True)
+    status: str = Field(index=True)
     auth_config: dict = Field(sa_column=Column(JSON))
     integration_id: uuid.UUID = Field(foreign_key="integration.id")
